import { ApiProperty } from "@nestjs/swagger"
import { MoneyUpdateType } from "@prisma/client"
import { Type } from "class-transformer"
import { IsEnum, IsInt, IsOptional, IsUUID } from "class-validator"

export class CreateMoneyUpdateDto {
  @IsInt()
  @Type(() => Number)
  @ApiProperty({ description: "Solde avant modification" })
  before: number

  @IsInt()
  @Type(() => Number)
  @ApiProperty({ description: "Solde après modification" })
  after: number

  @IsEnum(MoneyUpdateType)
  @ApiProperty({ description: "Type de modification de solde" })
  reason: MoneyUpdateType

  @IsOptional()
  @IsInt()
  @Type(() => Number)
  @ApiProperty({ description: "Identifiant de la réalisation de défi, si la mise à jour est liée à un défi", nullable: true })
  actionId?: number

  @IsOptional()
  @IsUUID()
  @ApiProperty({ description: "Identifiant du trajet acheté, si la mise à jour est liée à la réservation d'un train", nullable: true })
  tripId?: string
}
